@@ -91,8 +91,16 @@
 #define MENU_PATH_BOOKMARKS_PLACEHOLDER			"/menu/Bookmarks/Bookmarks Placeholder"
 
 #define COMMAND_PATH_CLOSE_WINDOW			"/commands/Close"
+#define COMMAND_SHOW_HIDE_SIDEBAR                       "/commands/Show Hide Sidebar"
+#define COMMAND_SHOW_HIDE_TOOLBAR                       "/commands/Show Hide Toolbar"
+#define COMMAND_SHOW_HIDE_LOCATION_BAR                  "/commands/Show Hide Location Bar"
+#define COMMAND_SHOW_HIDE_STATUS_BAR                    "/commands/Show Hide Statusbar"
+
+#define ID_SHOW_HIDE_SIDEBAR                            "Show Hide Sidebar"
+#define ID_SHOW_HIDE_TOOLBAR                            "Show Hide Toolbar"
+#define ID_SHOW_HIDE_LOCATION_BAR                       "Show Hide Location Bar"
+#define ID_SHOW_HIDE_STATUS_BAR                         "Show Hide Statusbar"
 
-#define USER_MANUAL_URI		"help:nautilus-user-manual"
 #define START_HERE_URI          "start-here:"
 
 #define RESPONSE_FORGET		1000
@@ -317,6 +325,15 @@ go_menu_start_here_callback (BonoboUIComponent *component,
 			       START_HERE_URI);
 }
 
+static void
+go_menu_go_to_trash_callback (BonoboUIComponent *component, 
+			      gpointer user_data, 
+			      const char *verb) 
+{
+	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
+			       EEL_TRASH_URI);
+}
+
 static void
 forget_history_if_yes (GtkDialog *dialog, int response, gpointer callback_data)
 {
@@ -343,12 +360,12 @@ forget_history_if_confirmed (NautilusWindow *window)
 		prompt = g_strdup (_("Are you sure you want to forget history? "
 				     "If you do, you will be doomed to repeat it."));
 	} else {
-		prompt = g_strdup (_("Are you sure you want Nautilus to forget "
-				     "which locations you have visited?"));
+		prompt = g_strdup (_("Are you sure you want to clear the list "
+				     "of locations you have visited?"));
 	}
 					   
 	dialog = eel_create_question_dialog (prompt,
-					     _("Clear History?"), 
+					     _("Clear History"), 
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     GTK_STOCK_CLEAR, RESPONSE_FORGET,
 					     GTK_WINDOW (window));
@@ -380,62 +397,94 @@ view_menu_reload_callback (BonoboUIComponent *component,
 }
 
 static void
-view_menu_show_hide_sidebar_callback (BonoboUIComponent *component, 
-			              gpointer user_data, 
-			              const char *verb) 
+view_menu_show_hide_sidebar_state_changed_callback (BonoboUIComponent *component, 
+						    const char *path,
+						    Bonobo_UIComponent_EventType type,
+						    const char *state,
+						    gpointer user_data)
 {
 	NautilusWindow *window;
 
 	window = NAUTILUS_WINDOW (user_data);
-	if (nautilus_window_sidebar_showing (window)) {
-		nautilus_window_hide_sidebar (window);
-	} else {
+
+        if (strcmp (state, "") == 0) {
+                /* State goes blank when component is removed; ignore this. */
+                return;
+        }
+
+	if (!strcmp (state, "1")) {
 		nautilus_window_show_sidebar (window);
+	} else {
+		nautilus_window_hide_sidebar (window);
 	}
 }
 
 static void
-view_menu_show_hide_toolbar_callback (BonoboUIComponent *component, 
-			               gpointer user_data, 
-			               const char *verb) 
+view_menu_show_hide_toolbar_state_changed_callback (BonoboUIComponent *component, 
+						    const char *path,
+						    Bonobo_UIComponent_EventType type,
+						    const char *state,
+						    gpointer user_data)
 {
 	NautilusWindow *window;
 
 	window = NAUTILUS_WINDOW (user_data);
-	if (nautilus_window_toolbar_showing (window)) {
-		nautilus_window_hide_toolbar (window);
-	} else {
+
+        if (strcmp (state, "") == 0) {
+                /* State goes blank when component is removed; ignore this. */
+                return;
+        }
+
+	if (!strcmp (state, "1")) {
 		nautilus_window_show_toolbar (window);
+	} else {
+		nautilus_window_hide_toolbar (window);
 	}
 }
 
 static void
-view_menu_show_hide_location_bar_callback (BonoboUIComponent *component, 
-			                   gpointer user_data, 
-			                   const char *verb) 
+view_menu_show_hide_location_bar_state_changed_callback (BonoboUIComponent *component, 
+							 const char *path,
+							 Bonobo_UIComponent_EventType type,
+							 const char *state,
+							 gpointer user_data)
 {
 	NautilusWindow *window;
 
 	window = NAUTILUS_WINDOW (user_data);
-	if (nautilus_window_location_bar_showing (window)) {
-		nautilus_window_hide_location_bar (window);
-	} else {
+
+        if (strcmp (state, "") == 0) {
+                /* State goes blank when component is removed; ignore this. */
+                return;
+        }
+
+	if (!strcmp (state, "1")) {
 		nautilus_window_show_location_bar (window);
+	} else {
+		nautilus_window_hide_location_bar (window);
 	}
 }
 
 static void
-view_menu_show_hide_status_bar_callback (BonoboUIComponent *component, 
-			                 gpointer user_data, 
-			                 const char *verb) 
+view_menu_show_hide_statusbar_state_changed_callback (BonoboUIComponent *component, 
+						      const char *path,
+						      Bonobo_UIComponent_EventType type,
+						      const char *state,
+						      gpointer user_data)
 {
 	NautilusWindow *window;
 
 	window = NAUTILUS_WINDOW (user_data);
-	if (nautilus_window_status_bar_showing (window)) {
-		nautilus_window_hide_status_bar (window);
-	} else {
+
+        if (strcmp (state, "") == 0) {
+                /* State goes blank when component is removed; ignore this. */
+                return;
+        }
+
+	if (!strcmp (state, "1")) {
 		nautilus_window_show_status_bar (window);
+	} else {
+		nautilus_window_hide_status_bar (window);
 	}
 }
 
@@ -447,29 +496,20 @@ nautilus_window_update_show_hide_menu_items (NautilusWindow *window)
 	nautilus_window_ui_freeze (window);
 
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
-	nautilus_bonobo_set_label (window->details->shell_ui,
-				   MENU_PATH_SHOW_HIDE_STATUS_BAR,
-				   nautilus_window_status_bar_showing (window)
-				   ? _("Hide St_atus Bar")
-				   : _("Show St_atus Bar"));
 		
-	nautilus_bonobo_set_label (window->details->shell_ui,
-				   MENU_PATH_SHOW_HIDE_SIDEBAR,
-				   nautilus_window_sidebar_showing (window)
-				   ? _("Hide _Sidebar")
-				   : _("Show _Sidebar"));
+	nautilus_bonobo_set_toggle_state (window->details->shell_ui,
+					  COMMAND_SHOW_HIDE_SIDEBAR,
+					  nautilus_window_sidebar_showing (window));
+	nautilus_bonobo_set_toggle_state (window->details->shell_ui,
+					  COMMAND_SHOW_HIDE_TOOLBAR,
+					  nautilus_window_toolbar_showing (window));
+	nautilus_bonobo_set_toggle_state (window->details->shell_ui,
+					  COMMAND_SHOW_HIDE_LOCATION_BAR,
+					  nautilus_window_location_bar_showing (window));
+	nautilus_bonobo_set_toggle_state (window->details->shell_ui,
+					  COMMAND_SHOW_HIDE_STATUS_BAR,
+					  nautilus_window_status_bar_showing (window));
 
-	nautilus_bonobo_set_label (window->details->shell_ui,
-				   MENU_PATH_SHOW_HIDE_TOOLBAR,
-				   nautilus_window_toolbar_showing (window)
-				   ? _("Hide _Toolbar")
-				   : _("Show _Toolbar"));
-		
-	nautilus_bonobo_set_label (window->details->shell_ui,
-				   MENU_PATH_SHOW_HIDE_LOCATION_BAR,
-				   nautilus_window_location_bar_showing (window)
-				   ? _("Hide Location _Bar")
-				   : _("Show Location _Bar"));
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 
 	nautilus_window_ui_thaw (window);
@@ -786,6 +826,7 @@ append_bookmark_to_menu (NautilusWindow *window,
 	nautilus_window_ui_thaw (window);
 }
 
+#ifdef WEB_NAVIGATION_ENABLED
 static char *
 get_static_bookmarks_file_path (void)
 {
@@ -803,7 +844,7 @@ get_static_bookmarks_file_path (void)
 	g_free (user_directory_path);
 	
 	/* get the mod date of the built-in static bookmarks file */
-	built_in_xml_file_path = nautilus_make_path (NAUTILUS_DATADIR, STATIC_BOOKMARKS_FILE_NAME);
+	built_in_xml_file_path = g_build_filename (NAUTILUS_DATADIR, STATIC_BOOKMARKS_FILE_NAME, NULL);
 	built_in_exists = g_file_test (built_in_xml_file_path, G_FILE_TEST_EXISTS);
 	
 	/* if we only have one file, return its path as the one to use */
@@ -849,6 +890,7 @@ get_static_bookmarks_file_path (void)
 	
 	return result;
 }
+#endif
 
 static void
 append_separator (NautilusWindow *window, const char *path)
@@ -910,6 +952,7 @@ create_menu_item_from_node (NautilusWindow *window,
 	nautilus_window_ui_thaw (window);
 }
 
+#ifdef WEB_NAVIGATION_ENABLED
 static void
 append_static_bookmarks (NautilusWindow *window, const char *menu_path)
 {
@@ -937,6 +980,7 @@ append_static_bookmarks (NautilusWindow *window, const char *menu_path)
 	
 	xmlFreeDoc(doc);
 }
+#endif
 
 static NautilusBookmarkList *bookmarks = NULL;
 
@@ -1020,9 +1064,11 @@ refresh_bookmarks_menu (NautilusWindow *window)
 
 	nautilus_window_remove_bookmarks_menu_items (window);
 
+#ifdef WEB_NAVIGATION_ENABLED
 	if (!eel_preferences_get_boolean (NAUTILUS_PREFERENCES_HIDE_BUILT_IN_BOOKMARKS)) {
 		append_static_bookmarks (window, MENU_PATH_BUILT_IN_BOOKMARKS_PLACEHOLDER);
 	}
+#endif
 
 	append_dynamic_bookmarks (window);
 
@@ -1104,13 +1150,10 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB ("Up", go_menu_up_callback),
 		BONOBO_UI_VERB ("Home", go_menu_home_callback),
 		BONOBO_UI_VERB ("Start Here", go_menu_start_here_callback),
+		BONOBO_UI_VERB ("Go to Trash", go_menu_go_to_trash_callback),
 		BONOBO_UI_VERB ("Go to Location", go_menu_location_callback),
 		BONOBO_UI_VERB ("Clear History", go_menu_forget_history_callback),
 		BONOBO_UI_VERB ("Reload", view_menu_reload_callback),
-		BONOBO_UI_VERB ("Show Hide Sidebar", view_menu_show_hide_sidebar_callback),
-		BONOBO_UI_VERB ("Show Hide Toolbar", view_menu_show_hide_toolbar_callback),
-		BONOBO_UI_VERB ("Show Hide Location Bar", view_menu_show_hide_location_bar_callback),
-		BONOBO_UI_VERB ("Show Hide Statusbar", view_menu_show_hide_status_bar_callback),
 		BONOBO_UI_VERB ("Zoom In", view_menu_zoom_in_callback),
 		BONOBO_UI_VERB ("Zoom Out", view_menu_zoom_out_callback),
 		BONOBO_UI_VERB ("Zoom Normal", view_menu_zoom_normal_callback),
@@ -1137,9 +1180,30 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
 
+	nautilus_window_update_show_hide_menu_items (window);
+
 	bonobo_ui_component_add_verb_list_with_data (window->details->shell_ui, verbs, window);
 
-        nautilus_window_update_show_hide_menu_items (window);
+	bonobo_ui_component_add_listener
+		(window->details->shell_ui,
+		 ID_SHOW_HIDE_SIDEBAR,
+		 view_menu_show_hide_sidebar_state_changed_callback, 
+		 window);
+	bonobo_ui_component_add_listener
+		(window->details->shell_ui,
+		 ID_SHOW_HIDE_TOOLBAR,
+		 view_menu_show_hide_toolbar_state_changed_callback, 
+		 window); 
+	bonobo_ui_component_add_listener
+		(window->details->shell_ui,
+		 ID_SHOW_HIDE_LOCATION_BAR,
+		 view_menu_show_hide_location_bar_state_changed_callback, 
+		 window);
+	bonobo_ui_component_add_listener
+		(window->details->shell_ui,
+		 ID_SHOW_HIDE_STATUS_BAR,
+		 view_menu_show_hide_statusbar_state_changed_callback, 
+		 window);
 
 	/* Register to catch Bonobo UI events so we can notice View As changes */
 	g_signal_connect_object (window->details->shell_ui, "ui_event", 
@@ -1330,5 +1394,3 @@ schedule_refresh_go_menu (NautilusWindow *window)
                                         window);
 	}	
 }
-
-
